import { useState, useEffect, useMemo } from "react";

const screenSizeLimits = {
  mobile: 768,
  tablet: 992
};

type WindowsSize = {
  width: number;
  height: number;
};

const useWindowSize = (delay = 0) => {
  const [windowSize, setWindowSize] = useState<WindowsSize>({
    width: window.innerWidth,
    height: window.innerHeight
  });

  useEffect(() => {
    let resizeTimeout: NodeJS.Timeout;

    // Handler to call on window resize
    function handleResize() {
      clearTimeout(resizeTimeout);
      resizeTimeout = setTimeout(() => {
        // Set window width/height to state
        setWindowSize({
          width: window.innerWidth,
          height: window.innerHeight
        });
      }, delay);
    }
    // Add event listener
    window.addEventListener("resize", handleResize);

    // Call handler right away so state gets updated with initial window size
    handleResize();

    return () => {
      clearTimeout(resizeTimeout);

      // Remove event listener on cleanup
      window.removeEventListener("resize", handleResize);
    };
  }, [delay]);

  const isMobile = useMemo(() => !!windowSize && windowSize.width < screenSizeLimits.mobile, [windowSize]);
  const isTablet = useMemo(
    () => !!windowSize && windowSize.width >= screenSizeLimits.mobile && windowSize.width < screenSizeLimits.tablet,
    [windowSize]
  );
  const isDesktop = useMemo(() => !!windowSize && windowSize.width >= screenSizeLimits.tablet, [windowSize]);

  return {
    windowSize,
    isMobile,
    isTablet,
    isDesktop
  };
};

export default useWindowSize;
